//
//  ResponseError.swift
//  WolfManagementMobile
//
//  Created by Tobias on 14.12.19.
//  Copyright © 2019 Tobias. All rights reserved.
//

import Foundation

public enum ResponseError: Error
{
    public enum AuthError: Error
    {
        case unauthorized
        case forbidden
    }

    public enum NetworkError: Error
    {
        case noInternet
        case timeout
        case serverNotFound
        case unknown(error: Error)
    }

    public enum HttpError: Error
    {
        case badRequest
        case notFound
        case internalError
        case raw(code: Int)
    }

    case requestError
    case typeError
    case authError(url: String, error: AuthError)
    case httpError(url: String, error: HttpError)
    case networkError(url: String, error: NetworkError)
    case clientError(url: String, error: Error)

    public static func getErrorForStatusCode(url: String, code: Int) -> ResponseError {
        switch code {
        case 400:
            return ResponseError.httpError(url: url, error: .badRequest)

        case 403:
            return ResponseError.authError(url: url, error: .forbidden)

        case 404:
            return ResponseError.httpError(url: url, error: .notFound)

        case 500:
            return ResponseError.httpError(url: url, error: .internalError)

        default:
            return ResponseError.httpError(url: url, error: .raw(code: code))
        }
    }
}
